==> react-headroom-1.8.2.tgz: package/examples/examples.js <==
/* eslint-disable max-len */
import React, { Component } from 'react'
import Headroom from '../src/index'
import { Container } from 'react-responsive-grid'

export default class Examples extends Component {
  render () {
    return (
      <div style={{ marginBottom: 64 }}>
        <Headroom
          onPin={() => console.log('pinned')}
          onUnpin={() => console.log('unpinned')}
          wrapperStyle={{ marginBottom: '3rem' }}
          style={{
            background: '#FF9800',
            boxShadow: '1px 2px 2px #aaa',
          }}
        >
          <Container style={{ maxWidth: '1000px', padding: '0 1.5rem' }}>
            <h1
              style={{
                margin: 0,
                padding: '.75rem 0',
                color: 'white',
              }}
            >
              React Headroom
            </h1>
          </Container>
        </Headroom>
        <Container style={{ maxWidth: '1000px', padding: '0 1.5rem' }}>
          <div>
            <a href="https://github.com/KyleAMathews/react-headroom">Code on Github</a>
            <p>React Headroom is a React Component to hide/show your header
            on scroll.
            The header on this site is a living example. When you scroll down, it
            slides out of view and slides back in when scrolling up.
            </p>
            <p>Fixed headers are nice for persistent navigation but they
            can also get in the way by taking up valuable vertical screen space.
            Using this component let's you have your persistent navigation while
            preserving screen space when the navigation is not needed.
            </p>

            <h2>Install</h2>
            <code>npm install react-headroom</code>

            <h2>Using React Headroom</h2>
            <p>It's very simple actually :)</p>
            <p>Here's an example:</p>

            <pre><code>
            {`
              <Headroom>
                <h1>You can put anything you'd like inside the Headroom Component</h1>
              </Headroom>
            `}
            </code></pre>

            <h3>Overriding animation</h3>

            <p>The component is intended to be plug n' play meaning it has sensible
            defaults for animating the header in and out. If you'd like to override
            the default animation, you have two options.
            </p>
            <p>One option is you can override the default inline styles like the following
            example:
            </p>

            <pre><code>
            {`
              <Headroom style={{
                webkitTransition: 'all .5s ease-in-out'
                mozTransition: 'all .5s ease-in-out'
                oTransition: 'all .5s ease-in-out'
                transition: 'all .5s ease-in-out'
              }}>
                <h1>You can put anything you'd like inside the Headroom Component</h1>
              </Headroom>
            `}
            </code></pre>

            <p>Another option is to use css. The component has a <code>headroom</code> class
            as well as a <code>headroom--pinned</code> or <code>headroom--unpinned</code> depending on its
            pinned state. As css can't override inline styles, first disable
            the animation styles by passing in the <code>disableInlineStyles</code> prop. Then in
            your css do something like:
            </p>

            <pre><code>
            {`
            .headroom {
              transition: transform 200ms linear;
              position: fixed;
              left: 0;
              right: 0;
              top: 0;
              zIndex: 1;
            }
            .headroom--pinned {
              transform: translateY(0%);
            }
            .headroom--unpinned {
              transform: translateY(-100%);
            }
            `}
            </code></pre>

            <h3>Other props</h3>
            <ul>
              <li><code>onPin</code> — callback called when header is pinned</li>
              <li><code>onUnpin</code> — callback called when header is unpinned</li>
              <li><code>upTolerance</code> — scroll tolerance in px when scrolling up before component is pinned</li>
              <li><code>downTolerance</code> — scroll tolerance in px when scrolling down before component is pinned</li>
              <li><code>disable</code> — disable pinning and unpinning</li>
              <li><code>wrapperStyle</code> — pass styles to be added to the wrapper div (this maintains the components vertical space at the top of the page).</li>
              <li><code>parent</code> — provide a custom 'parent' element for scroll events. <code>parent</code> should be a function which resolves to the desired element.</li>
              <li><code>pinStart</code> — height in px where the header should start and stop pinning. Useful when you have another element above Headroom component.</li>
            </ul>
          </div>
        </Container>
      </div>
    )
  }
}

==> react-headroom-1.8.4.tgz: package/examples/examples.js <==
/* eslint-disable max-len */
import React, { Component } from 'react'
import Headroom from '../src/index'
import { Container } from 'react-responsive-grid'

export default class Examples extends Component {
  render () {
    return (
      <div style={{ marginBottom: 64 }}>
        <Headroom
          onPin={() => console.log('pinned')}
          onUnpin={() => console.log('unpinned')}
          wrapperStyle={{ marginBottom: '3rem' }}
          style={{
            background: '#FF9800',
            boxShadow: '1px 2px 2px #aaa',
          }}
        >
          <Container style={{ maxWidth: '1000px', padding: '0 1.5rem' }}>
            <h1
              style={{
                margin: 0,
                padding: '.75rem 0',
                color: 'white',
              }}
            >
              React Headroom
            </h1>
          </Container>
        </Headroom>
        <Container style={{ maxWidth: '1000px', padding: '0 1.5rem' }}>
          <div>
            <a href="https://github.com/KyleAMathews/react-headroom">Code on Github</a>
            <p>React Headroom is a React Component to hide/show your header
            on scroll.
            The header on this site is a living example. When you scroll down, it
            slides out of view and slides back in when scrolling up.
            </p>
            <p>Fixed headers are nice for persistent navigation but they
            can also get in the way by taking up valuable vertical screen space.
            Using this component let's you have your persistent navigation while
            preserving screen space when the navigation is not needed.
            </p>

            <h2>Install</h2>
            <code>npm install react-headroom</code>

            <h2>Using React Headroom</h2>
            <p>It's very simple actually :)</p>
            <p>Here's an example:</p>

            <pre><code>
            {`
              <Headroom>
                <h1>You can put anything you'd like inside the Headroom Component</h1>
              </Headroom>
            `}
            </code></pre>

            <h3>Overriding animation</h3>

            <p>The component is intended to be plug n' play meaning it has sensible
            defaults for animating the header in and out. If you'd like to override
            the default animation, you have two options.
            </p>
            <p>One option is you can override the default inline styles like the following
            example:
            </p>

            <pre><code>
            {`
              <Headroom style={{
                webkitTransition: 'all .5s ease-in-out'
                mozTransition: 'all .5s ease-in-out'
                oTransition: 'all .5s ease-in-out'
                transition: 'all .5s ease-in-out'
              }}>
                <h1>You can put anything you'd like inside the Headroom Component</h1>
              </Headroom>
            `}
            </code></pre>

            <p>
              Another option is to use css. The component has a <code>headroom</code> class
              as well as a <code>headroom--pinned</code> or <code>headroom--unpinned</code> depending on its
              pinned state. As css can't override inline styles, first disable
              the animation styles by passing in the <code>disableInlineStyles</code> prop. Then in
              your css do something like:
            </p>

            <pre><code>
            {`
            .headroom {
              transition: transform 200ms linear;
              position: fixed;
              left: 0;
              right: 0;
              top: 0;
              zIndex: 1;
            }
            .headroom--pinned {
              transform: translateY(0%);
            }
            .headroom--unpinned {
              transform: translateY(-100%);
            }
            `}
            </code></pre>

            <h3>Other props</h3>
            <ul>
              <li><code>onPin</code> — callback called when header is pinned</li>
              <li><code>onUnpin</code> — callback called when header is unpinned</li>
              <li><code>upTolerance</code> — scroll tolerance in px when scrolling up before component is pinned</li>
              <li><code>downTolerance</code> — scroll tolerance in px when scrolling down before component is pinned</li>
              <li><code>disable</code> — disable pinning and unpinning</li>
              <li><code>wrapperStyle</code> — pass styles to be added to the wrapper div (this maintains the components vertical space at the top of the page).</li>
              <li><code>parent</code> — provide a custom 'parent' element for scroll events. <code>parent</code> should be a function which resolves to the desired element.</li>
              <li><code>pinStart</code> — height in px where the header should start and stop pinning. Useful when you have another element above Headroom component.</li>
            </ul>
          </div>
        </Container>
      </div>
    )
  }
}
